.. Orange3 Text Mining documentation master file, created by
   sphinx-quickstart on Fri May  8 15:18:26 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Orange3 Text Mining's documentation!
===============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/preprocess.rst

Scripting Reference
-------------------

.. toctree::
   :maxdepth: 1

   scripting/corpus.rst
   scripting/lda.rst
   scripting/preprocess.rst
   scripting/nyt.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

